@@ -14,15 +14,16 @@
 
 #include "kdevstringhandler.h"
 
-#include <QStringList>
-#include <QString>
-#include <QStringRef>
 #include <QByteArray>
 #include <QChar>
 #include <QDataStream>
-#include <QVariant>
-#include <QRegExp>
+#include <QIODevice>
+#include <QRegularExpression>
+#include <QString>
+#include <QStringList>
+#include <QStringView>
 #include <QTextDocument>
+#include <QVariant>
 
 #include <algorithm>
 #include <cctype>
@@ -105,8 +106,9 @@ QString htmlToPlainText(const QString& s, HtmlToPlainTextMode mode)
 {
     switch (mode) {
     case FastMode: {
+        static const QRegularExpression htmlTagRegex(QStringLiteral("<[^>]+>"));
         QString result(s);
-        result.remove(QRegExp(QStringLiteral("<[^>]+>")));
+        result.remove(htmlTagRegex);
         return result;
     }
     case CompleteMode: {
@@ -162,7 +164,7 @@ QByteArray escapeJavaScriptString(const QByteArray& str)
 }
 }
 
-int KDevelop::findAsciiIdentifierLength(const QStringRef& str)
+int KDevelop::findAsciiIdentifierLength(QStringView str)
 {
     if (str.isEmpty()) {
         return 0;
@@ -183,7 +185,7 @@ int KDevelop::findAsciiIdentifierLength(const QStringRef& str)
     return std::find_if_not(str.cbegin() + 1, str.cend(), partOfIdentifier) - str.cbegin();
 }
 
-KDevelop::VariableMatch KDevelop::matchPossiblyBracedAsciiVariable(const QStringRef& str)
+KDevelop::VariableMatch KDevelop::matchPossiblyBracedAsciiVariable(QStringView str)
 {
     if (str.isEmpty()) {
         return {};
@@ -224,7 +226,7 @@ QString KDevelop::stripAnsiSequences(const QString& str)
     } state = PLAIN;
 
     QString result;
-    result.reserve(str.count());
+    result.reserve(str.size());
 
     for (const QChar c : str) {
         const auto val = c.unicode();
@@ -281,6 +283,7 @@ void KDevelop::normalizeLineEndings(QByteArray& text)
         }
         if (i + 1 < s && text[i + 1] == '\n') {
             text.remove(i, 1);
+            s -= 1;
         } else {
             text[i] = '\n';
         }
