@@ -8,7 +8,7 @@
 #include "svndiffjob_p.h"
 
 #include <QMutexLocker>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QFileInfo>
 
@@ -24,6 +24,7 @@
 
 #include "svnclient.h"
 
+namespace {
 ///@todo The subversion library returns borked diffs, where the headers are at the end. This function
 ///           takes those headers, and moves them into the correct place to create a valid working diff.
 ///           Find the source of this problem.
@@ -33,31 +34,30 @@ QString repairDiff(const QString& diff) {
     QMap<QString, QString> headers;
     for(int a = 0; a < lines.size()-1; ++a) {
         const QLatin1String indexLineBegin("Index: ");
-        if(lines[a].startsWith(indexLineBegin) && lines[a+1].startsWith(QLatin1String("====="))) {
-            const QString fileName = lines[a].midRef(indexLineBegin.size()).trimmed().toString();
-            headers[fileName] = lines[a];
+        if (lines.at(a).startsWith(indexLineBegin) && lines.at(a + 1).startsWith(QLatin1String("====="))) {
+            const auto fileName = QStringView{lines.at(a)}.mid(indexLineBegin.size()).trimmed().toString();
+            headers[fileName] = lines.at(a);
             qCDebug(PLUGIN_SVN) << "found header for" << fileName;
             lines[a] = QString();
-            if(lines[a+1].startsWith(QLatin1String("======"))) {
-                headers[fileName] += QLatin1Char('\n') + lines[a+1];
-            lines[a+1] = QString();
+            if (lines.at(a + 1).startsWith(QLatin1String("======"))) {
+                headers[fileName] += QLatin1Char('\n') + lines.at(a + 1);
+                lines[a + 1] = QString();
             }
         }
     }
 
-    QRegExp spaceRegExp(QStringLiteral("\\s"));
-
+    static const QRegularExpression whitespaceRegex(QStringLiteral("\\s"));
     for(int a = 0; a < lines.size()-1; ++a) {
         const QLatin1String threeDashLineBegin("--- ");
-        if(lines[a].startsWith(threeDashLineBegin)) {
-            QString tail = lines[a].mid(threeDashLineBegin.size());
-            if(tail.indexOf(spaceRegExp) != -1) {
-                QString file = tail.left(tail.indexOf(spaceRegExp));
+        if (lines.at(a).startsWith(threeDashLineBegin)) {
+            const auto tail = lines.at(a).mid(threeDashLineBegin.size());
+            if (const auto whitespaceIndex = tail.indexOf(whitespaceRegex); whitespaceIndex != -1) {
+                const auto file = tail.left(whitespaceIndex);
                 qCDebug(PLUGIN_SVN) << "checking for" << file;
                 const auto headerIt = headers.constFind(file);
                 if (headerIt != headers.constEnd()) {
                     qCDebug(PLUGIN_SVN) << "adding header for" << file << ":" << *headerIt;
-                    lines[a] = *headerIt + QLatin1Char('\n') + lines[a];
+                    lines[a] = *headerIt + QLatin1Char('\n') + lines.at(a);
                 }
             }
         }
@@ -67,6 +67,8 @@ QString repairDiff(const QString& diff) {
     return ret;
 }
 
+} // unnamed namespace
+
 //@TODO: Handle raw diffs by using SvnCatJob to fetch both files/revisions
 
 SvnInternalDiffJob::SvnInternalDiffJob( SvnJobBase* parent )
